/*
 * *********************************************************************************************************************************************
 * "THE BEER-WARE LICENSE" (Revision 42):
 * Mario Hellmich <mario.hellmich@web.de> wrote this file. As long as you retain this
 * notice you can do whatever you want with this stuff. If we meet some day,
 * and you think this stuff is worth it, you can buy me a beer in return.
 * Mario Hellmich
 * *********************************************************************************************************************************************
 * def.h
 *
 * Version 1.0
 *
 * Created: 29.05.2017
 * Author: Mario Hellmich <mario.hellmich@web.de>
 *
 * This file contains definitions of the individual bits in intr_state, the front panel key codes, and the constants maximal
 * and minimal tunable frequency, maximal and minimal COR level, and maximal and minimal COR level.
 */ 


// Define asm NOP and CPU clock
#define F_CPU 16000000UL																	// CPU clock is 16 MHz
#define NOP() asm volatile("nop")


// Instrument state bits in instr_state
#define AM					0
#define USB					1
#define LSB					2
#define MUTE				3
#define MUTE_SELECTED		4
#define AGC_FAST			5
#define AGC_SLOW			6
#define AGC_HANG			7
#define MGC					8
#define BW1					9
#define BW2					10
#define BW3					11
#define TUNE_100KHZ			12
#define TUNE_10KHZ			13
#define TUNE_1KHZ			14
#define TUNE_100HZ			15
#define TUNE_10HZ			16
#define TUNE_LOCK			17
#define SET_COR				18
#define COR_ACTIVE			19
#define BFO_TUNE			20
#define ATT_ON				21



// Front panel key codes																	   Component designator:
#define KEY_AM				1																// S1
#define KEY_USB				2																// S4
#define KEY_LSB				3																// S7
#define KEY_MUTE			4																// S10
#define KEY_FAST			5																// S13
#define KEY_SLOW			6																// S15
#define KEY_HANG			7																// S17
#define KEY_MGC				8																// S19
#define KEY_BW1				9																// S2
#define KEY_BW2				10																// S5
#define KEY_BW3				11																// S8
#define KEY_TLOCK			12																// S11
#define KEY_10HZ			13																// S14
#define KEY_100HZ			14																// S16
#define KEY_1KHZ			15																// S18
#define KEY_10KHZ			16																// S20
#define KEY_100KHZ			17																// S3
#define KEY_SETCOR			18																// S6
#define KEY_BFOTUNE			19																// S9
#define KEY_ATT				20																// S12


// Error code bits in instr_error
#define ERR_RSSI_RANGE		0																// RSSI voltage out of permissible range
#define ERR_PLL_LOL			1																// Loss of lock error in PLL synthesizer
#define ERR_STUCK_KEY		2																// Stuck key at startup


// Constants
#define MIN_COR_LEVEL		120																// Minimum COR level is -120 dBm, below that COR is always enabled
#define MAX_COR_LEVEL		0																// Maximum COR level is 0 dBm
#define MAX_FREQ			30000000														// Max frequency (in Hz) the receiver can be tuned to, i.e. 30.000,000 MHz, tuning and display resolution 10 Hz
#define MIN_FREQ			1000															// Min Frequency (in Hz) the receiver can be tuned to, i.e. 00.001,000 MHz
#define MAX_BFO_OFFS		3500															// Max BFO offset (in Hz) that can be selected
#define MIN_BFO_OFFS		-3500															// Min BFO offset (in Hz) that can be selected