/*
 * *********************************************************************************************************************************************
 * "THE BEER-WARE LICENSE" (Revision 42):
 * Mario Hellmich <mario.hellmich@web.de> wrote this file. As long as you retain this
 * notice you can do whatever you want with this stuff. If we meet some day,
 * and you think this stuff is worth it, you can buy me a beer in return.
 * Mario Hellmich
 * *********************************************************************************************************************************************
 * fault.c
 *
 * Version 1.0
 *
 * Created: 29.05.2017
 * Author: Mario Hellmich <mario.hellmich@web.de>
 *
 * Self check functions and hardware error routines
 */ 


#include <avr/io.h>
#include <avr/interrupt.h>

#include "fault.h"
#include "def.h"

extern volatile uint32_t instr_state;
extern volatile uint8_t  instr_error;
extern volatile uint8_t  annunc_pattern[13];




/*
************************************************************************************************************************************************
Self check functions:
The MCU periodically checks the loss of lock signal of the Si5341 PLL synthesizer and displays an error code if a loss of lock is detected. 
*/

#define FAULTDET_PORT		PORTD
#define FAULTDET_PIN		PIND
#define FAULTDET_DDR		DDRD
#define PIN_LOL				PIND3

void fault_init(void)
{
	FAULTDET_DDR  &= ~( (1<<PIN_LOL) );														// Set PIN_LOL as input
	FAULTDET_PORT &= ~( (1<<PIN_LOL) );														// Do not use the internal pull up on PIN_LOL
}

void handle_error(uint8_t error_code)
{
	instr_error |= (1<<error_code);															// Set appropriate error flag in instr_error	
}

void clear_error(uint8_t error_code)
{
	instr_error &= ~( (1<<error_code) );													// Clear flag in instr_error
}


/*
************************************************************************************************************************************************
Testing for loss of lock of the PLL synthesizer:
This function is called periodically in the main function.
*/

void PLL_fault_test(void)
{
	if( !( FAULTDET_PIN & (1<<PIN_LOL) ) )												// Does the Si5341 indicate no loss of lock?
		clear_error(ERR_PLL_LOL);												
	else																				// Loss of lock detected, set error flag
		handle_error(ERR_PLL_LOL);
}