/*
 * *********************************************************************************************************************************************
 * "THE BEER-WARE LICENSE" (Revision 42):
 * Mario Hellmich <mario.hellmich@web.de> wrote this file. As long as you retain this
 * notice you can do whatever you want with this stuff. If we meet some day,
 * and you think this stuff is worth it, you can buy me a beer in return.
 * Mario Hellmich
 * *********************************************************************************************************************************************
 * si5341.h
 *
 * Version 1.0
 *
 * Created: 29.05.2017
 * Author: Mario Hellmich <mario.hellmich@web.de>
 *
 * Controls the Si5341 PLL synthesizer for LO1, LO2, and the BFO, via the TWI bus
 */ 


#ifndef SI5341_H_
#define SI5341_H_


// Type Definitions
typedef union
{
	uint32_t i32;
	uint8_t byte[4];
} convert32to8;

typedef union
{
	uint64_t i64;
	uint8_t byte[8];
} convert64to8;


/* File Scope Variables */
extern const uint32_t roofing_filt_freq;
extern const uint32_t if_freq;


/* Functions */
extern void TWI_init(void);
extern void TWI_start(void);
extern void TWI_stop(void);
extern void TWI_write(uint8_t data);
extern uint8_t TWI_read_ACK(void);
extern uint8_t TWI_read_NACK(void);
extern uint8_t TWI_get_status(void);
extern void si5341_write_register(uint8_t addr, uint8_t target_register, uint8_t val);
extern void si5341_write_consec(uint8_t addr, uint8_t start_reg_addr, uint8_t num, uint8_t *write_buffer);
extern uint8_t si5341_read_register(uint8_t addr, uint8_t register_addr);
extern void si5341_read_consec(uint8_t addr, uint8_t start_addr_register, uint8_t num, uint8_t *read_buffer);
extern void set_page(uint8_t page);
extern void si5341_init(void);
extern void lo1_set_freq(uint32_t freq);
extern void lo2_set_freq(uint32_t freq);
extern void bfo_set_freq(uint32_t freq);
extern void freq_init(void);
extern void freq_update(void);



#endif /* SI5341_H_ */